import UIKit
import SnapKit
import BiometricAuthentication

class UnauthorizedPartViewController: UIViewController {

    override func viewDidLoad() {
        super.viewDidLoad()
        
        title = "Unauthorized Part"
        view.backgroundColor = .white

        let loginButton = ButtonsFactory.createDefaultButton(title: "Login", target: self, onTapAction: #selector(onLogin))
        view.addSubview(loginButton)
        loginButton.snp.makeConstraints {
            $0.center.equalToSuperview()
        }
    }
    
    @objc
    private func onLogin() {
        guard BioMetricAuthenticator.canAuthenticate() else {
            print("Can't authenticate")
            return
        }
        
        BioMetricAuthenticator.shared.allowableReuseDuration = 10
        
        BioMetricAuthenticator.authenticateWithBioMetrics(reason: "") { [weak self] result in
            switch result {
                case .success( _):
                    print("Authentication Successful")
                    self?.moveToAuthorizedPart()
                case .failure(let error):
                    print("Authentication Failed. Error: \(error)")
                }
        }
    }
    
    private func moveToAuthorizedPart() {
        navigationController?.pushViewController(AuthorizedPartViewController(), animated: true)
    }


}

